var namespacenanovdb =
[
    [ "io", "namespacenanovdb_1_1io.html", "namespacenanovdb_1_1io" ],
    [ "util", "namespacenanovdb_1_1util.html", "namespacenanovdb_1_1util" ],
    [ "tools", "namespacenanovdb_1_1tools.html", "namespacenanovdb_1_1tools" ],
    [ "GridHandleMetaData", "structnanovdb_1_1GridHandleMetaData.html", "structnanovdb_1_1GridHandleMetaData" ],
    [ "GridHandle", "classnanovdb_1_1GridHandle.html", "classnanovdb_1_1GridHandle" ],
    [ "BufferTraits", "structnanovdb_1_1BufferTraits.html", "structnanovdb_1_1BufferTraits" ],
    [ "HostBuffer", "classnanovdb_1_1HostBuffer.html", "classnanovdb_1_1HostBuffer" ],
    [ "ValueIndex", "classnanovdb_1_1ValueIndex.html", null ],
    [ "ValueOnIndex", "classnanovdb_1_1ValueOnIndex.html", null ],
    [ "ValueIndexMask", "classnanovdb_1_1ValueIndexMask.html", null ],
    [ "ValueOnIndexMask", "classnanovdb_1_1ValueOnIndexMask.html", null ],
    [ "ValueMask", "classnanovdb_1_1ValueMask.html", null ],
    [ "Half", "classnanovdb_1_1Half.html", null ],
    [ "Fp4", "classnanovdb_1_1Fp4.html", null ],
    [ "Fp8", "classnanovdb_1_1Fp8.html", null ],
    [ "Fp16", "classnanovdb_1_1Fp16.html", null ],
    [ "FpN", "classnanovdb_1_1FpN.html", null ],
    [ "Point", "classnanovdb_1_1Point.html", null ],
    [ "BuildTraits", "structnanovdb_1_1BuildTraits.html", "structnanovdb_1_1BuildTraits" ],
    [ "BuildToValueMap", "structnanovdb_1_1BuildToValueMap.html", "structnanovdb_1_1BuildToValueMap" ],
    [ "BuildToValueMap&lt; ValueIndex &gt;", "structnanovdb_1_1BuildToValueMap_3_01ValueIndex_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueIndex_01_4" ],
    [ "BuildToValueMap&lt; ValueOnIndex &gt;", "structnanovdb_1_1BuildToValueMap_3_01ValueOnIndex_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueOnIndex_01_4" ],
    [ "BuildToValueMap&lt; ValueIndexMask &gt;", "structnanovdb_1_1BuildToValueMap_3_01ValueIndexMask_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueIndexMask_01_4" ],
    [ "BuildToValueMap&lt; ValueOnIndexMask &gt;", "structnanovdb_1_1BuildToValueMap_3_01ValueOnIndexMask_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueOnIndexMask_01_4" ],
    [ "BuildToValueMap&lt; ValueMask &gt;", "structnanovdb_1_1BuildToValueMap_3_01ValueMask_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueMask_01_4" ],
    [ "BuildToValueMap&lt; Half &gt;", "structnanovdb_1_1BuildToValueMap_3_01Half_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Half_01_4" ],
    [ "BuildToValueMap&lt; Fp4 &gt;", "structnanovdb_1_1BuildToValueMap_3_01Fp4_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Fp4_01_4" ],
    [ "BuildToValueMap&lt; Fp8 &gt;", "structnanovdb_1_1BuildToValueMap_3_01Fp8_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Fp8_01_4" ],
    [ "BuildToValueMap&lt; Fp16 &gt;", "structnanovdb_1_1BuildToValueMap_3_01Fp16_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Fp16_01_4" ],
    [ "BuildToValueMap&lt; FpN &gt;", "structnanovdb_1_1BuildToValueMap_3_01FpN_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01FpN_01_4" ],
    [ "BuildToValueMap&lt; Point &gt;", "structnanovdb_1_1BuildToValueMap_3_01Point_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Point_01_4" ],
    [ "Version", "classnanovdb_1_1Version.html", "classnanovdb_1_1Version" ],
    [ "TensorTraits", "structnanovdb_1_1TensorTraits.html", null ],
    [ "TensorTraits&lt; T, 0 &gt;", "structnanovdb_1_1TensorTraits_3_01T_00_010_01_4.html", "structnanovdb_1_1TensorTraits_3_01T_00_010_01_4" ],
    [ "TensorTraits&lt; T, 1 &gt;", "structnanovdb_1_1TensorTraits_3_01T_00_011_01_4.html", "structnanovdb_1_1TensorTraits_3_01T_00_011_01_4" ],
    [ "FloatTraits", "structnanovdb_1_1FloatTraits.html", "structnanovdb_1_1FloatTraits" ],
    [ "FloatTraits&lt; T, 8 &gt;", "structnanovdb_1_1FloatTraits_3_01T_00_018_01_4.html", "structnanovdb_1_1FloatTraits_3_01T_00_018_01_4" ],
    [ "FloatTraits&lt; bool, 1 &gt;", "structnanovdb_1_1FloatTraits_3_01bool_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01bool_00_011_01_4" ],
    [ "FloatTraits&lt; ValueIndex, 1 &gt;", "structnanovdb_1_1FloatTraits_3_01ValueIndex_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueIndex_00_011_01_4" ],
    [ "FloatTraits&lt; ValueIndexMask, 1 &gt;", "structnanovdb_1_1FloatTraits_3_01ValueIndexMask_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueIndexMask_00_011_01_4" ],
    [ "FloatTraits&lt; ValueOnIndex, 1 &gt;", "structnanovdb_1_1FloatTraits_3_01ValueOnIndex_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueOnIndex_00_011_01_4" ],
    [ "FloatTraits&lt; ValueOnIndexMask, 1 &gt;", "structnanovdb_1_1FloatTraits_3_01ValueOnIndexMask_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueOnIndexMask_00_011_01_4" ],
    [ "FloatTraits&lt; ValueMask, 1 &gt;", "structnanovdb_1_1FloatTraits_3_01ValueMask_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueMask_00_011_01_4" ],
    [ "FloatTraits&lt; Point, 1 &gt;", "structnanovdb_1_1FloatTraits_3_01Point_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01Point_00_011_01_4" ],
    [ "BitArray", "structnanovdb_1_1BitArray.html", null ],
    [ "BitArray&lt; 8 &gt;", "structnanovdb_1_1BitArray_3_018_01_4.html", "structnanovdb_1_1BitArray_3_018_01_4" ],
    [ "BitArray&lt; 16 &gt;", "structnanovdb_1_1BitArray_3_0116_01_4.html", "structnanovdb_1_1BitArray_3_0116_01_4" ],
    [ "BitArray&lt; 32 &gt;", "structnanovdb_1_1BitArray_3_0132_01_4.html", "structnanovdb_1_1BitArray_3_0132_01_4" ],
    [ "BitArray&lt; 64 &gt;", "structnanovdb_1_1BitArray_3_0164_01_4.html", "structnanovdb_1_1BitArray_3_0164_01_4" ],
    [ "BitFlags", "classnanovdb_1_1BitFlags.html", "classnanovdb_1_1BitFlags" ],
    [ "Mask", "classnanovdb_1_1Mask.html", "classnanovdb_1_1Mask" ],
    [ "Map", "structnanovdb_1_1Map.html", "structnanovdb_1_1Map" ],
    [ "GridBlindMetaData", "structnanovdb_1_1GridBlindMetaData.html", "structnanovdb_1_1GridBlindMetaData" ],
    [ "NodeTrait", "structnanovdb_1_1NodeTrait.html", null ],
    [ "NodeTrait&lt; GridOrTreeOrRootT, 0 &gt;", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_010_01_4.html", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_010_01_4" ],
    [ "NodeTrait&lt; const GridOrTreeOrRootT, 0 &gt;", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_010_01_4.html", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_010_01_4" ],
    [ "NodeTrait&lt; GridOrTreeOrRootT, 1 &gt;", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_011_01_4.html", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_011_01_4" ],
    [ "NodeTrait&lt; const GridOrTreeOrRootT, 1 &gt;", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_011_01_4.html", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_011_01_4" ],
    [ "NodeTrait&lt; GridOrTreeOrRootT, 2 &gt;", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_012_01_4.html", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_012_01_4" ],
    [ "NodeTrait&lt; const GridOrTreeOrRootT, 2 &gt;", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_012_01_4.html", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_012_01_4" ],
    [ "NodeTrait&lt; GridOrTreeOrRootT, 3 &gt;", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_013_01_4.html", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_013_01_4" ],
    [ "NodeTrait&lt; const GridOrTreeOrRootT, 3 &gt;", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_013_01_4.html", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_013_01_4" ],
    [ "GetValue", "structnanovdb_1_1GetValue.html", "structnanovdb_1_1GetValue" ],
    [ "SetValue", "structnanovdb_1_1SetValue.html", "structnanovdb_1_1SetValue" ],
    [ "SetVoxel", "structnanovdb_1_1SetVoxel.html", "structnanovdb_1_1SetVoxel" ],
    [ "GetState", "structnanovdb_1_1GetState.html", "structnanovdb_1_1GetState" ],
    [ "GetDim", "structnanovdb_1_1GetDim.html", "structnanovdb_1_1GetDim" ],
    [ "GetLeaf", "structnanovdb_1_1GetLeaf.html", "structnanovdb_1_1GetLeaf" ],
    [ "ProbeValue", "structnanovdb_1_1ProbeValue.html", "structnanovdb_1_1ProbeValue" ],
    [ "GetNodeInfo", "structnanovdb_1_1GetNodeInfo.html", "structnanovdb_1_1GetNodeInfo" ],
    [ "Checksum", "classnanovdb_1_1Checksum.html", "classnanovdb_1_1Checksum" ],
    [ "GridData", "structnanovdb_1_1GridData.html", "structnanovdb_1_1GridData" ],
    [ "ReadAccessor", "classnanovdb_1_1ReadAccessor.html", null ],
    [ "Grid", "classnanovdb_1_1Grid.html", "classnanovdb_1_1Grid" ],
    [ "TreeData", "structnanovdb_1_1TreeData.html", "structnanovdb_1_1TreeData" ],
    [ "GridTree", "structnanovdb_1_1GridTree.html", "structnanovdb_1_1GridTree" ],
    [ "GridTree&lt; const GridT &gt;", "structnanovdb_1_1GridTree_3_01const_01GridT_01_4.html", "structnanovdb_1_1GridTree_3_01const_01GridT_01_4" ],
    [ "Tree", "classnanovdb_1_1Tree.html", "classnanovdb_1_1Tree" ],
    [ "RootData", "structnanovdb_1_1RootData.html", "structnanovdb_1_1RootData" ],
    [ "RootNode", "classnanovdb_1_1RootNode.html", "classnanovdb_1_1RootNode" ],
    [ "InternalData", "structnanovdb_1_1InternalData.html", "structnanovdb_1_1InternalData" ],
    [ "InternalNode", "classnanovdb_1_1InternalNode.html", "classnanovdb_1_1InternalNode" ],
    [ "LeafData", "structnanovdb_1_1LeafData.html", "structnanovdb_1_1LeafData" ],
    [ "LeafFnBase", "structnanovdb_1_1LeafFnBase.html", "structnanovdb_1_1LeafFnBase" ],
    [ "LeafData&lt; Fp4, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01Fp4_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01Fp4_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
    [ "LeafData&lt; Fp8, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01Fp8_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01Fp8_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
    [ "LeafData&lt; Fp16, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01Fp16_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01Fp16_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
    [ "LeafData&lt; FpN, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01FpN_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01FpN_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
    [ "LeafData&lt; bool, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01bool_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01bool_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
    [ "LeafData&lt; ValueMask, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01ValueMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
    [ "LeafIndexBase", "structnanovdb_1_1LeafIndexBase.html", "structnanovdb_1_1LeafIndexBase" ],
    [ "LeafData&lt; ValueIndex, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01ValueIndex_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueIndex_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
    [ "LeafData&lt; ValueOnIndex, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01ValueOnIndex_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueOnIndex_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
    [ "LeafData&lt; ValueIndexMask, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01ValueIndexMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueIndexMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
    [ "LeafData&lt; ValueOnIndexMask, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01ValueOnIndexMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueOnIndexMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
    [ "LeafData&lt; Point, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01Point_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01Point_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
    [ "LeafNode", "classnanovdb_1_1LeafNode.html", "classnanovdb_1_1LeafNode" ],
    [ "NanoNode", "structnanovdb_1_1NanoNode.html", null ],
    [ "NanoNode&lt; BuildT, 0 &gt;", "structnanovdb_1_1NanoNode_3_01BuildT_00_010_01_4.html", "structnanovdb_1_1NanoNode_3_01BuildT_00_010_01_4" ],
    [ "NanoNode&lt; BuildT, 1 &gt;", "structnanovdb_1_1NanoNode_3_01BuildT_00_011_01_4.html", "structnanovdb_1_1NanoNode_3_01BuildT_00_011_01_4" ],
    [ "NanoNode&lt; BuildT, 2 &gt;", "structnanovdb_1_1NanoNode_3_01BuildT_00_012_01_4.html", "structnanovdb_1_1NanoNode_3_01BuildT_00_012_01_4" ],
    [ "NanoNode&lt; BuildT, 3 &gt;", "structnanovdb_1_1NanoNode_3_01BuildT_00_013_01_4.html", "structnanovdb_1_1NanoNode_3_01BuildT_00_013_01_4" ],
    [ "ReadAccessor&lt; BuildT, -1, -1, -1 &gt;", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01-1_00_01-1_00_01-1_01_4.html", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01-1_00_01-1_00_01-1_01_4" ],
    [ "ReadAccessor&lt; BuildT, LEVEL0, -1, -1 &gt;", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01LEVEL0_00_01-1_00_01-1_01_4.html", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01LEVEL0_00_01-1_00_01-1_01_4" ],
    [ "ReadAccessor&lt; BuildT, LEVEL0, LEVEL1, -1 &gt;", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01LEVEL0_00_01LEVEL1_00_01-1_01_4.html", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01LEVEL0_00_01LEVEL1_00_01-1_01_4" ],
    [ "ReadAccessor&lt; BuildT, 0, 1, 2 &gt;", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_010_00_011_00_012_01_4.html", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_010_00_011_00_012_01_4" ],
    [ "GridMetaData", "classnanovdb_1_1GridMetaData.html", "classnanovdb_1_1GridMetaData" ],
    [ "PointAccessor", "classnanovdb_1_1PointAccessor.html", "classnanovdb_1_1PointAccessor" ],
    [ "PointAccessor&lt; AttT, Point &gt;", "classnanovdb_1_1PointAccessor_3_01AttT_00_01Point_01_4.html", "classnanovdb_1_1PointAccessor_3_01AttT_00_01Point_01_4" ],
    [ "ChannelAccessor", "classnanovdb_1_1ChannelAccessor.html", "classnanovdb_1_1ChannelAccessor" ],
    [ "GetLower", "structnanovdb_1_1GetLower.html", "structnanovdb_1_1GetLower" ],
    [ "GetUpper", "structnanovdb_1_1GetUpper.html", "structnanovdb_1_1GetUpper" ],
    [ "GetTile", "structnanovdb_1_1GetTile.html", "structnanovdb_1_1GetTile" ],
    [ "NodeManager", "classnanovdb_1_1NodeManager.html", "classnanovdb_1_1NodeManager" ],
    [ "NodeManagerHandle", "classnanovdb_1_1NodeManagerHandle.html", "classnanovdb_1_1NodeManagerHandle" ],
    [ "NodeManagerData", "structnanovdb_1_1NodeManagerData.html", "structnanovdb_1_1NodeManagerData" ],
    [ "Range", "classnanovdb_1_1Range.html", null ],
    [ "Timer", "classnanovdb_1_1Timer.html", "classnanovdb_1_1Timer" ],
    [ "BoolGrid", "namespacenanovdb.html#a44c7484144fab7fb2c436e938e2d87ce", null ],
    [ "BoolTree", "namespacenanovdb.html#ad72af753c2016641acc019c714d77f97", null ],
    [ "DefaultReadAccessor", "namespacenanovdb.html#a119ba501e2785cede6a233e164587646", null ],
    [ "DoubleGrid", "namespacenanovdb.html#ae4044ab7ef1bfe752d228fe84ecd996e", null ],
    [ "DoubleTree", "namespacenanovdb.html#a89653a5be991c6944d23f78ab9a0d165", null ],
    [ "FloatGrid", "namespacenanovdb.html#a2ae45d4df056c7d0d936a496fec925ee", null ],
    [ "FloatTree", "namespacenanovdb.html#aea5691a16e345b5c9ccfecc9bd421aa3", null ],
    [ "Fp16Grid", "namespacenanovdb.html#a2add8370a07ef764607a1c02780a7ac9", null ],
    [ "Fp16Tree", "namespacenanovdb.html#ab24e02bf14f76279b005a547b7d7f014", null ],
    [ "Fp4Grid", "namespacenanovdb.html#a108f0bf38170451c71ed8757c5a252ad", null ],
    [ "Fp4Tree", "namespacenanovdb.html#aee38b4e88bb1acfba039bec3bda151fc", null ],
    [ "Fp8Grid", "namespacenanovdb.html#a6823526f3faca27de16d19bd6da323bd", null ],
    [ "Fp8Tree", "namespacenanovdb.html#a957c939d1a187968289b6668e4bbfccd", null ],
    [ "FpNGrid", "namespacenanovdb.html#aea5067ced91f635731e7bdfd93d8e4ab", null ],
    [ "FpNTree", "namespacenanovdb.html#ab70dae51348229b857c5baeb55634ede", null ],
    [ "IndexGrid", "namespacenanovdb.html#ad24384a4bda82649992fd5faf8fbbea4", null ],
    [ "IndexMaskGrid", "namespacenanovdb.html#ae110e094c8acbf86476a56e1a934db48", null ],
    [ "IndexMaskTree", "namespacenanovdb.html#ab435418aa35a94ca3e0e07106cdade3a", null ],
    [ "IndexTree", "namespacenanovdb.html#a8b2ce743deac24d5783b4c9c4ab2413c", null ],
    [ "Int32Grid", "namespacenanovdb.html#ad5315505f8bc162f1d371ea1d8beb559", null ],
    [ "Int32Tree", "namespacenanovdb.html#a7e3e7b41a25f7e3ea990ede00acf4b4d", null ],
    [ "Int64Grid", "namespacenanovdb.html#a6dac52fd0c0a5f0eb9ccac0050b951f9", null ],
    [ "Int64Tree", "namespacenanovdb.html#aa670cd82320c67592342219ede77f80a", null ],
    [ "MaskGrid", "namespacenanovdb.html#ab26e09c39606fb93509615cd9120d4b0", null ],
    [ "MaskTree", "namespacenanovdb.html#a58500ecb4f7084a799ab81316cbb6429", null ],
    [ "NanoGrid", "namespacenanovdb.html#a1eba1ecdc176671d534794bcd6604e8a", null ],
    [ "NanoLeaf", "namespacenanovdb.html#a7f5e063d2e00f072512023f71730e30c", null ],
    [ "NanoLower", "namespacenanovdb.html#a36ca82ec691cb6e38cd5d1910b38f849", null ],
    [ "NanoRoot", "namespacenanovdb.html#a537a4d5b445c163b39b264a0788e4acc", null ],
    [ "NanoTree", "namespacenanovdb.html#a7414dd62bd9510809baa893a7fe34f45", null ],
    [ "NanoUpper", "namespacenanovdb.html#a4a37fa5d76eaf814e849b1041127f4d6", null ],
    [ "OnIndexGrid", "namespacenanovdb.html#a64b12ea5a9ec908880ce61ade6cfe2c7", null ],
    [ "OnIndexMaskGrid", "namespacenanovdb.html#a1f5a34bcde78736b2a932d86dad38952", null ],
    [ "OnIndexMaskTree", "namespacenanovdb.html#a52f690d3f9a2e77d10430b2246e5135a", null ],
    [ "OnIndexTree", "namespacenanovdb.html#a81835ea06bc64d48949f2d38c055dfd7", null ],
    [ "PointGrid", "namespacenanovdb.html#a5179ca634b95e51e1e60c3137966121a", null ],
    [ "UInt32Grid", "namespacenanovdb.html#a94e1a92c88ebc5f570edaaf87d7b478e", null ],
    [ "UInt32Tree", "namespacenanovdb.html#ad9b036304ed2c809aed2b227c786055c", null ],
    [ "Vec3dGrid", "namespacenanovdb.html#a50c6d355efc86c8636e15ec43bc73600", null ],
    [ "Vec3dTree", "namespacenanovdb.html#ab09734db37c7e5175ebd599a3fbc2e42", null ],
    [ "Vec3fGrid", "namespacenanovdb.html#a2f55df6ff6e3e428413c6695c27ebf06", null ],
    [ "Vec3fTree", "namespacenanovdb.html#ad6e9f607aae5a2c0b3a4a98e9c91cc78", null ],
    [ "Vec3IGrid", "namespacenanovdb.html#a667cf1ae46101764bb15844228daef4d", null ],
    [ "Vec3ITree", "namespacenanovdb.html#a262735ef3ecf29bd0fd96861e644450b", null ],
    [ "Vec4dGrid", "namespacenanovdb.html#a38929ef24ddc9df8bb8ee096c8a21663", null ],
    [ "Vec4dTree", "namespacenanovdb.html#a91fd90b78e816b5286c89d9f5d59dd02", null ],
    [ "Vec4fGrid", "namespacenanovdb.html#a1e6db5e5a91cff3cd3929f2b634b91d7", null ],
    [ "Vec4fTree", "namespacenanovdb.html#aa9473db48ae9bdb558ed7af023ad9f9f", null ],
    [ "CheckMode", "namespacenanovdb.html#a4e857e4b13a164e4df80f9282a71d0b5", [
      [ "Disable", "namespacenanovdb.html#a4e857e4b13a164e4df80f9282a71d0b5abcfaccebf745acfd5e75351095a5394a", null ],
      [ "Empty", "namespacenanovdb.html#a4e857e4b13a164e4df80f9282a71d0b5ace2c8aed9c2fa0cfbed56cbda4d8bf07", null ],
      [ "Half", "namespacenanovdb.html#a4e857e4b13a164e4df80f9282a71d0b5ac48615a1bc4197056d522af276aa5a85", null ],
      [ "Partial", "namespacenanovdb.html#a4e857e4b13a164e4df80f9282a71d0b5a44ffd38a6dea695cbe2b34efdcc6cf27", null ],
      [ "Default", "namespacenanovdb.html#a4e857e4b13a164e4df80f9282a71d0b5a7a1920d61156abc05a60135aefe8bc67", null ],
      [ "Full", "namespacenanovdb.html#a4e857e4b13a164e4df80f9282a71d0b5abbd47109890259c0127154db1af26c75", null ],
      [ "End", "namespacenanovdb.html#a4e857e4b13a164e4df80f9282a71d0b5a87557f11575c0ad78e4e28abedc13b6e", null ],
      [ "StrLen", "namespacenanovdb.html#a4e857e4b13a164e4df80f9282a71d0b5a3b057f70b2c3c127066f1555ea066942", null ]
    ] ],
    [ "GridBlindDataClass", "namespacenanovdb.html#a88f2aa0b172a229831be2b4e1c70e757", [
      [ "Unknown", "namespacenanovdb.html#a88f2aa0b172a229831be2b4e1c70e757a88183b946cc5f0e8c96b2e66e1c74a7e", null ],
      [ "IndexArray", "namespacenanovdb.html#a88f2aa0b172a229831be2b4e1c70e757aacaaf217c6534c34b63edcbbf5b422d5", null ],
      [ "AttributeArray", "namespacenanovdb.html#a88f2aa0b172a229831be2b4e1c70e757ac9f80f42ad87935afb0e58d931cac637", null ],
      [ "GridName", "namespacenanovdb.html#a88f2aa0b172a229831be2b4e1c70e757ae2b04d8578fddb43d1dd7b17e0938f8c", null ],
      [ "ChannelArray", "namespacenanovdb.html#a88f2aa0b172a229831be2b4e1c70e757a6c726c41d16ff146b47662a778b25364", null ],
      [ "End", "namespacenanovdb.html#a88f2aa0b172a229831be2b4e1c70e757a87557f11575c0ad78e4e28abedc13b6e", null ]
    ] ],
    [ "GridBlindDataSemantic", "namespacenanovdb.html#ad302dde29b8cf276217e7db12f56e1ea", [
      [ "Unknown", "namespacenanovdb.html#ad302dde29b8cf276217e7db12f56e1eaa88183b946cc5f0e8c96b2e66e1c74a7e", null ],
      [ "PointPosition", "namespacenanovdb.html#ad302dde29b8cf276217e7db12f56e1eaa5c3b53b495a3a3675a13b9f920f65c68", null ],
      [ "PointColor", "namespacenanovdb.html#ad302dde29b8cf276217e7db12f56e1eaa755bd5308e91265618dfe6d16bab5827", null ],
      [ "PointNormal", "namespacenanovdb.html#ad302dde29b8cf276217e7db12f56e1eaaceed7a7fc0fffbe1eeda2b27b73fe970", null ],
      [ "PointRadius", "namespacenanovdb.html#ad302dde29b8cf276217e7db12f56e1eaa41b2451b41584afbc9a2aae375df887e", null ],
      [ "PointVelocity", "namespacenanovdb.html#ad302dde29b8cf276217e7db12f56e1eaa844465b2d78929eccef953b476a1d3ae", null ],
      [ "PointId", "namespacenanovdb.html#ad302dde29b8cf276217e7db12f56e1eaaffee0e6895c7bbb8ad956f9cdc43f05f", null ],
      [ "WorldCoords", "namespacenanovdb.html#ad302dde29b8cf276217e7db12f56e1eaaad398e268b887627d9060fa8107829c4", null ],
      [ "GridCoords", "namespacenanovdb.html#ad302dde29b8cf276217e7db12f56e1eaaacf4f1b1f76cca12828cb0c1f61262c7", null ],
      [ "VoxelCoords", "namespacenanovdb.html#ad302dde29b8cf276217e7db12f56e1eaa7572a22ae44e59c3d4f906392ccb0081", null ],
      [ "End", "namespacenanovdb.html#ad302dde29b8cf276217e7db12f56e1eaa87557f11575c0ad78e4e28abedc13b6e", null ]
    ] ],
    [ "GridClass", "namespacenanovdb.html#a4b4b8c3c2fb135839b2d1b020cc06538", [
      [ "Unknown", "namespacenanovdb.html#a4b4b8c3c2fb135839b2d1b020cc06538a88183b946cc5f0e8c96b2e66e1c74a7e", null ],
      [ "LevelSet", "namespacenanovdb.html#a4b4b8c3c2fb135839b2d1b020cc06538af75f97f8f1058acd62c93bf29de9f49e", null ],
      [ "FogVolume", "namespacenanovdb.html#a4b4b8c3c2fb135839b2d1b020cc06538a2863212e81b8902a3bff99d2006ce625", null ],
      [ "Staggered", "namespacenanovdb.html#a4b4b8c3c2fb135839b2d1b020cc06538af421d06a10620aa57ae6ebaec46cffe9", null ],
      [ "PointIndex", "namespacenanovdb.html#a4b4b8c3c2fb135839b2d1b020cc06538ac6672402f95bb6a565b10c45206e7073", null ],
      [ "PointData", "namespacenanovdb.html#a4b4b8c3c2fb135839b2d1b020cc06538ae540450fb956cd9dbb96f979e5939d0f", null ],
      [ "Topology", "namespacenanovdb.html#a4b4b8c3c2fb135839b2d1b020cc06538a99571eecaa5c5d622bb0d1f855752d5f", null ],
      [ "VoxelVolume", "namespacenanovdb.html#a4b4b8c3c2fb135839b2d1b020cc06538a72123f854e9cd15456c7bec1065d6fb2", null ],
      [ "IndexGrid", "namespacenanovdb.html#a4b4b8c3c2fb135839b2d1b020cc06538acb1be051e0c63143e5435c90f3145716", null ],
      [ "TensorGrid", "namespacenanovdb.html#a4b4b8c3c2fb135839b2d1b020cc06538a592c282b872320d6af38c4155b1692fe", null ],
      [ "End", "namespacenanovdb.html#a4b4b8c3c2fb135839b2d1b020cc06538a87557f11575c0ad78e4e28abedc13b6e", null ],
      [ "StrLen", "namespacenanovdb.html#a4b4b8c3c2fb135839b2d1b020cc06538a3b057f70b2c3c127066f1555ea066942", null ]
    ] ],
    [ "GridFlags", "namespacenanovdb.html#a5e907cd4aa4176a71501fbc59bcd6bb2", [
      [ "HasLongGridName", "namespacenanovdb.html#a5e907cd4aa4176a71501fbc59bcd6bb2a23e9b13b57fa3a257e1e4fde6cf56877", null ],
      [ "HasBBox", "namespacenanovdb.html#a5e907cd4aa4176a71501fbc59bcd6bb2a9f37cc46fd863dea1ffb9c259dbb7c00", null ],
      [ "HasMinMax", "namespacenanovdb.html#a5e907cd4aa4176a71501fbc59bcd6bb2a263a3063d285be389e148e85421039f7", null ],
      [ "HasAverage", "namespacenanovdb.html#a5e907cd4aa4176a71501fbc59bcd6bb2a0a62d056892be87e60f9e076e1527ad7", null ],
      [ "HasStdDeviation", "namespacenanovdb.html#a5e907cd4aa4176a71501fbc59bcd6bb2a162fc94d271294bc85d49f150e78e7f6", null ],
      [ "IsBreadthFirst", "namespacenanovdb.html#a5e907cd4aa4176a71501fbc59bcd6bb2ad502f4662163332c1da3eee696195a5d", null ],
      [ "End", "namespacenanovdb.html#a5e907cd4aa4176a71501fbc59bcd6bb2a87557f11575c0ad78e4e28abedc13b6e", null ],
      [ "StrLen", "namespacenanovdb.html#a5e907cd4aa4176a71501fbc59bcd6bb2a3b057f70b2c3c127066f1555ea066942", null ]
    ] ],
    [ "GridType", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0", [
      [ "Unknown", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a88183b946cc5f0e8c96b2e66e1c74a7e", null ],
      [ "Float", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a22ae0e2b89e5e3d477f988cc36d3272b", null ],
      [ "Double", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0ad909d38d705ce75386dd86e611a82f5b", null ],
      [ "Int16", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a39bc2ae44b184207f560ff8619823208", null ],
      [ "Int32", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0ac06129f6e6e15c09328365e553f1dc31", null ],
      [ "Int64", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0afbde23b11d7e59af7828e81144c8b487", null ],
      [ "Vec3f", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0ae955b77fe1f267cbe6bb898c6be66369", null ],
      [ "Vec3d", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0ad5b40ccec7be098557d1e35969a4bec2", null ],
      [ "Mask", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a4a18312b5b75f549d5551e5912ad6ebf", null ],
      [ "Half", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0ac48615a1bc4197056d522af276aa5a85", null ],
      [ "UInt32", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0ae7956ed7be1c5025a27ed3cb42a396bd", null ],
      [ "Boolean", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a27226c864bac7454a8504f8edb15d95b", null ],
      [ "RGBA8", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0ab4b279046a02077466fa26cabb00c642", null ],
      [ "Fp4", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a3f84fc6967b5ab092b8a07a4b5e88cc5", null ],
      [ "Fp8", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a7ca0d07c477bfb061380581840f9d8b1", null ],
      [ "Fp16", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0afe294cd6f9909150e9ab48cdebcc2caa", null ],
      [ "FpN", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0ab2baef78f0e38560077dd76b13478677", null ],
      [ "Vec4f", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a34d3ecfb06b4ed93cf8d67757d968331", null ],
      [ "Vec4d", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a6344916c470b2c1e9fb91cbdff70b601", null ],
      [ "Index", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a88fa71f0a6e0dfedbb46d91cc0b37a50", null ],
      [ "OnIndex", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0ac3922cc108832ec8e5a5702cdc9cb283", null ],
      [ "IndexMask", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a6f46c6bc461374535922d91fde2c9a61", null ],
      [ "OnIndexMask", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a4af32108e62136a074a40a815f3994f9", null ],
      [ "PointIndex", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0ac6672402f95bb6a565b10c45206e7073", null ],
      [ "Vec3u8", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a1451f42309a1af14dd6f615503ea9744", null ],
      [ "Vec3u16", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a58feb259a4420759cff617e92d459498", null ],
      [ "UInt8", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0ab31df9c476d20e85ff898121efe11b5a", null ],
      [ "End", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a87557f11575c0ad78e4e28abedc13b6e", null ],
      [ "StrLen", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a3b057f70b2c3c127066f1555ea066942", null ]
    ] ],
    [ "MagicType", "namespacenanovdb.html#aa0895e3576a80fc34b25fff786b1d108", [
      [ "Unknown", "namespacenanovdb.html#aa0895e3576a80fc34b25fff786b1d108a88183b946cc5f0e8c96b2e66e1c74a7e", null ],
      [ "OpenVDB", "namespacenanovdb.html#aa0895e3576a80fc34b25fff786b1d108a011b949ced7ed48dafe7b08ae740dae9", null ],
      [ "NanoVDB", "namespacenanovdb.html#aa0895e3576a80fc34b25fff786b1d108a88a126c378054f0ba911c58116fdaf43", null ],
      [ "NanoGrid", "namespacenanovdb.html#aa0895e3576a80fc34b25fff786b1d108a723913be2557a3dcfe17866296fee5b6", null ],
      [ "NanoFile", "namespacenanovdb.html#aa0895e3576a80fc34b25fff786b1d108acabfde358eaaeaff8df932f1346f0bcf", null ],
      [ "End", "namespacenanovdb.html#aa0895e3576a80fc34b25fff786b1d108a87557f11575c0ad78e4e28abedc13b6e", null ],
      [ "StrLen", "namespacenanovdb.html#aa0895e3576a80fc34b25fff786b1d108a3b057f70b2c3c127066f1555ea066942", null ]
    ] ],
    [ "PointType", "namespacenanovdb.html#a141c0fdf5a91c32310d552d4c357699b", [
      [ "Disable", "namespacenanovdb.html#a141c0fdf5a91c32310d552d4c357699babcfaccebf745acfd5e75351095a5394a", null ],
      [ "PointID", "namespacenanovdb.html#a141c0fdf5a91c32310d552d4c357699ba86bbf6c1606325c980585d136866fb2f", null ],
      [ "World64", "namespacenanovdb.html#a141c0fdf5a91c32310d552d4c357699bad7ae19b0bbc6fe3695b1b8f6f36e932f", null ],
      [ "World32", "namespacenanovdb.html#a141c0fdf5a91c32310d552d4c357699ba91a7dc3cc2ea0ed2215b1ade139b1bcf", null ],
      [ "Grid64", "namespacenanovdb.html#a141c0fdf5a91c32310d552d4c357699bae145abf20f8b2a7c8d5612e8961e9b32", null ],
      [ "Grid32", "namespacenanovdb.html#a141c0fdf5a91c32310d552d4c357699ba12c5c9b2e2a77edcefa82d80dde5ff80", null ],
      [ "Voxel32", "namespacenanovdb.html#a141c0fdf5a91c32310d552d4c357699ba0522330b37aac86ef9303c0686b543d4", null ],
      [ "Voxel16", "namespacenanovdb.html#a141c0fdf5a91c32310d552d4c357699bacf9278b5e5db74c7c099e8694a2476c4", null ],
      [ "Voxel8", "namespacenanovdb.html#a141c0fdf5a91c32310d552d4c357699ba1784e0952706051e3000cc167eec72a5", null ],
      [ "Default", "namespacenanovdb.html#a141c0fdf5a91c32310d552d4c357699ba7a1920d61156abc05a60135aefe8bc67", null ],
      [ "End", "namespacenanovdb.html#a141c0fdf5a91c32310d552d4c357699ba87557f11575c0ad78e4e28abedc13b6e", null ]
    ] ],
    [ "alignmentPadding", "namespacenanovdb.html#ab5114661378036785ecd28ccef4af4f7", null ],
    [ "alignPtr", "namespacenanovdb.html#accecca045f04c7971c65022455b29d93", null ],
    [ "callNanoGrid", "namespacenanovdb.html#a1b3135f716c47316e3fac411945de505", null ],
    [ "CountOn", "namespacenanovdb.html#a05d946bff32cf47312d136fff783e82a", null ],
    [ "cpyGridHandleMeta", "namespacenanovdb.html#a0aa7ba290bbd672413524413aae811e7", null ],
    [ "createAccessor", "namespacenanovdb.html#a57196e3b8c9a0bb6c2db0eecac532a3b", null ],
    [ "createAccessor", "namespacenanovdb.html#a757ad702d35c52b48de5efb3b3731422", null ],
    [ "createAccessor", "namespacenanovdb.html#a6357b61877db34bff22f605489ea892f", null ],
    [ "createNodeManager", "namespacenanovdb.html#aefce754e1e7397fb6d1a75c1eec1054b", null ],
    [ "FindHighestOn", "namespacenanovdb.html#a658495d0ebb6118f9703edf79645fe94", null ],
    [ "FindHighestOn", "namespacenanovdb.html#a02a61aeb177a12187d4f92b8b746ac28", null ],
    [ "FindLowestOn", "namespacenanovdb.html#ae9b773d887ae5eb938f18c3c557c8d45", null ],
    [ "FindLowestOn", "namespacenanovdb.html#abcb7a465c460c2eedab4a8b59af63ca7", null ],
    [ "forEach", "namespacenanovdb.html#a7cd7d9ef9958d5c86962f2c129091c4a", null ],
    [ "forEach", "namespacenanovdb.html#ac906357e63c1a3a9cffceacbf311d022", null ],
    [ "forEach", "namespacenanovdb.html#aa574309e3ddb090bd7973b0898dd95c0", null ],
    [ "invoke", "namespacenanovdb.html#a9fa34a074151d9dae08f4fcfcfc164f8", null ],
    [ "isAligned", "namespacenanovdb.html#a9c70a762c5052ffc60a53f34f9c60395", null ],
    [ "isFloatingPoint", "namespacenanovdb.html#a07d1356890f8bd7328eccd0ef6d6859b", null ],
    [ "isFloatingPointVector", "namespacenanovdb.html#a8e18498be5b1f04f98183216b96f5991", null ],
    [ "isIndex", "namespacenanovdb.html#ab9b68ed29001ffca257c5d7643306da6", null ],
    [ "isInteger", "namespacenanovdb.html#a30dacf83d229d27991e15c5ff1ac4d68", null ],
    [ "isValid", "namespacenanovdb.html#aadeb99b9975910f70061a7e05bdcdfdf", null ],
    [ "isValid", "namespacenanovdb.html#aa8b7a062a229b832fa603cba57fd45b2", null ],
    [ "mapToGridClass", "namespacenanovdb.html#ae3a4415a24f80ce1bc2c47d936cfb29e", null ],
    [ "mapToGridType", "namespacenanovdb.html#a7d6a90b0888cf68599da7f84a34cba0c", null ],
    [ "mergeGrids", "namespacenanovdb.html#a1999ea4347f33abf15bb667141a1f2df", null ],
    [ "prefixSum", "namespacenanovdb.html#ac06981b465ecffc4663e5b905abca429", null ],
    [ "reduce", "namespacenanovdb.html#a6944240b47d28520b2479e88cba70098", null ],
    [ "reduce", "namespacenanovdb.html#a8e86a9eb8e5d6ab2dd7e9cc0133b1039", null ],
    [ "reduce", "namespacenanovdb.html#a9bfe6769cee6e711d758b56c953192e8", null ],
    [ "splitGrids", "namespacenanovdb.html#a2d80d40ab0add4f3ab16c1cdbb50c2ce", null ],
    [ "strlen", "namespacenanovdb.html#a1b76c2c1dee8522993ff9a1ad9ebf696", null ],
    [ "toCheckMode", "namespacenanovdb.html#a1ee58c66a6f478961a2a0841d242ba15", null ],
    [ "toGridClass", "namespacenanovdb.html#afd47b48286b4d63b8f993dc9214c621a", null ],
    [ "toGridType", "namespacenanovdb.html#a1fd46c7c96fb30e3eb3424e20d39273c", null ],
    [ "toMagic", "namespacenanovdb.html#a42a6d5a3554f41e16097456a904b782f", null ],
    [ "toStr", "namespacenanovdb.html#a6cb4be28da153a7c9563ff3a277e5ab0", null ],
    [ "toStr", "namespacenanovdb.html#a067b4d80252fc3eb9ae76c8bcb0b44c9", null ],
    [ "toStr", "namespacenanovdb.html#a502d64c8e599f96c192772c6b702d675", null ],
    [ "toStr", "namespacenanovdb.html#ae1a25f393cd58e2c66398956b09f2383", null ],
    [ "toStr", "namespacenanovdb.html#a22c8e7ad68f0f547562b7a000402eb92", null ],
    [ "toStr", "namespacenanovdb.html#a9816aa583e468678da051b0e570abf6e", null ]
];